pub struct CreateAccountSessionComponents {Show 19 fields
pub account_management: Option<AccountConfigParam>,
pub account_onboarding: Option<AccountConfigParam>,
pub balances: Option<PayoutsConfigParam>,
pub disputes_list: Option<CreateAccountSessionComponentsDisputesList>,
pub documents: Option<BaseConfigParam>,
pub financial_account: Option<CreateAccountSessionComponentsFinancialAccount>,
pub financial_account_transactions: Option<CreateAccountSessionComponentsFinancialAccountTransactions>,
pub instant_payouts_promotion: Option<CreateAccountSessionComponentsInstantPayoutsPromotion>,
pub issuing_card: Option<CreateAccountSessionComponentsIssuingCard>,
pub issuing_cards_list: Option<CreateAccountSessionComponentsIssuingCardsList>,
pub notification_banner: Option<AccountConfigParam>,
pub payment_details: Option<CreateAccountSessionComponentsPaymentDetails>,
pub payment_disputes: Option<CreateAccountSessionComponentsPaymentDisputes>,
pub payments: Option<CreateAccountSessionComponentsPayments>,
pub payout_details: Option<BaseConfigParam>,
pub payouts: Option<PayoutsConfigParam>,
pub payouts_list: Option<BaseConfigParam>,
pub tax_registrations: Option<BaseConfigParam>,
pub tax_settings: Option<BaseConfigParam>,
}Expand description
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
Fields
account_management: Option<AccountConfigParam>Configuration for the account management embedded component.
account_onboarding: Option<AccountConfigParam>Configuration for the account onboarding embedded component.
balances: Option<PayoutsConfigParam>Configuration for the balances embedded component.
disputes_list: Option<CreateAccountSessionComponentsDisputesList>Configuration for the disputes list embedded component.
documents: Option<BaseConfigParam>Configuration for the documents embedded component.
financial_account: Option<CreateAccountSessionComponentsFinancialAccount>Configuration for the financial account embedded component.
financial_account_transactions: Option<CreateAccountSessionComponentsFinancialAccountTransactions>Configuration for the financial account transactions embedded component.
instant_payouts_promotion: Option<CreateAccountSessionComponentsInstantPayoutsPromotion>Configuration for the instant payouts promotion embedded component.
issuing_card: Option<CreateAccountSessionComponentsIssuingCard>Configuration for the issuing card embedded component.
issuing_cards_list: Option<CreateAccountSessionComponentsIssuingCardsList>Configuration for the issuing cards list embedded component.
Configuration for the notification banner embedded component.
payment_details: Option<CreateAccountSessionComponentsPaymentDetails>Configuration for the payment details embedded component.
payment_disputes: Option<CreateAccountSessionComponentsPaymentDisputes>Configuration for the payment disputes embedded component.
payments: Option<CreateAccountSessionComponentsPayments>Configuration for the payments embedded component.
payout_details: Option<BaseConfigParam>Configuration for the payout details embedded component.
payouts: Option<PayoutsConfigParam>Configuration for the payouts embedded component.
payouts_list: Option<BaseConfigParam>Configuration for the payouts list embedded component.
tax_registrations: Option<BaseConfigParam>Configuration for the tax registrations embedded component.
tax_settings: Option<BaseConfigParam>Configuration for the tax settings embedded component.
Implementations