CreateAccountSessionComponentsDisputesListFeatures

Struct CreateAccountSessionComponentsDisputesListFeatures 

pub struct CreateAccountSessionComponentsDisputesListFeatures {
    pub capture_payments: Option<bool>,
    pub destination_on_behalf_of_charge_management: Option<bool>,
    pub dispute_management: Option<bool>,
    pub refund_management: Option<bool>,
}
The list of features enabled in the embedded component.

Fields

capture_payments: Option<bool>

Whether to allow capturing and cancelling payment intents. This is true by default.

destination_on_behalf_of_charge_management: Option<bool>

Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.

dispute_management: Option<bool>

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.

refund_management: Option<bool>

Whether sending refunds is enabled. This is true by default.

Implementations