pub struct CreateAccountSessionComponentsInstantPayoutsPromotionFeatures {
pub disable_stripe_user_authentication: Option<bool>,
pub external_account_collection: Option<bool>,
pub instant_payouts: Option<bool>,
}Expand description
The list of features enabled in the embedded component.
Fields
disable_stripe_user_authentication: Option<bool>Whether Stripe user authentication is disabled.
This value can only be true for accounts where controller.requirement_collection is application for the account.
The default value is the opposite of the external_account_collection value.
For example, if you don’t set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
external_account_collection: Option<bool>Whether external account collection is enabled.
This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts.
The default value for this feature is true.
instant_payouts: Option<bool>Whether instant payouts are enabled for this component.
Implementations