pub struct ConnectEmbeddedFinancialAccountFeatures {
pub disable_stripe_user_authentication: bool,
pub external_account_collection: bool,
pub send_money: bool,
pub transfer_balance: bool,
}Fields
disable_stripe_user_authentication: boolWhether Stripe user authentication is disabled.
This value can only be true for accounts where controller.requirement_collection is application for the account.
The default value is the opposite of the external_account_collection value.
For example, if you don’t set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
external_account_collection: boolWhether external account collection is enabled.
This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts.
The default value for this feature is true.
send_money: boolWhether to allow sending money.
transfer_balance: boolWhether to allow transferring balance.