pub struct LegalEntityRepresentativeDeclaration {
pub date: Option<i64>,
pub ip: Option<String>,
pub user_agent: Option<String>,
}Fields
date: Option<i64>The Unix timestamp marking when the representative declaration attestation was made.
ip: Option<String>The IP address from which the representative declaration attestation was made.
user_agent: Option<String>The user-agent string from the browser where the representative declaration attestation was made.