pub struct ConnectEmbeddedIssuingCardsListFeatures {
pub card_management: bool,
pub card_spend_dispute_management: bool,
pub cardholder_management: bool,
pub disable_stripe_user_authentication: bool,
pub spend_control_management: bool,
}Fields
card_management: boolWhether to allow card management features.
card_spend_dispute_management: boolWhether to allow card spend dispute management features.
cardholder_management: boolWhether to allow cardholder management features.
disable_stripe_user_authentication: boolWhether Stripe user authentication is disabled.
This value can only be true for accounts where controller.requirement_collection is application for the account.
The default value is the opposite of the external_account_collection value.
For example, if you don’t set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
spend_control_management: boolWhether to allow spend control management features.